pub struct BybitWsPlaceOrderParams {Show 29 fields
pub category: BybitProductType,
pub symbol: String,
pub side: String,
pub order_type: String,
pub qty: String,
pub is_leverage: Option<i32>,
pub market_unit: Option<String>,
pub price: Option<String>,
pub time_in_force: Option<String>,
pub order_link_id: Option<String>,
pub reduce_only: Option<bool>,
pub close_on_trigger: Option<bool>,
pub trigger_price: Option<String>,
pub trigger_by: Option<String>,
pub trigger_direction: Option<i32>,
pub tpsl_mode: Option<String>,
pub take_profit: Option<String>,
pub stop_loss: Option<String>,
pub tp_trigger_by: Option<String>,
pub sl_trigger_by: Option<String>,
pub sl_trigger_price: Option<String>,
pub tp_trigger_price: Option<String>,
pub sl_order_type: Option<String>,
pub tp_order_type: Option<String>,
pub sl_limit_price: Option<String>,
pub tp_limit_price: Option<String>,
pub order_iv: Option<String>,
pub mmp: Option<bool>,
pub position_idx: Option<BybitPositionIdx>,
}Expand description
Parameters for placing an order via WebSocket.
Fields
category: BybitProductTypesymbol: Stringside: Stringorder_type: Stringqty: Stringis_leverage: Option<i32>market_unit: Option<String>price: Option<String>time_in_force: Option<String>order_link_id: Option<String>reduce_only: Option<bool>close_on_trigger: Option<bool>trigger_price: Option<String>trigger_by: Option<String>trigger_direction: Option<i32>tpsl_mode: Option<String>take_profit: Option<String>stop_loss: Option<String>tp_trigger_by: Option<String>sl_trigger_by: Option<String>sl_trigger_price: Option<String>tp_trigger_price: Option<String>sl_order_type: Option<String>tp_order_type: Option<String>sl_limit_price: Option<String>tp_limit_price: Option<String>order_iv: Option<String>mmp: Option<bool>position_idx: Option<BybitPositionIdx>Trait Implementations
Sourceimpl Clone for BybitWsPlaceOrderParams
impl Clone for BybitWsPlaceOrderParams
Sourcefn clone(&self) -> BybitWsPlaceOrderParams
fn clone(&self) -> BybitWsPlaceOrderParams
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BybitWsPlaceOrderParams
impl Debug for BybitWsPlaceOrderParams
Sourceimpl From<BybitWsPlaceOrderParams> for BybitWsPlaceOrderParams
impl From<BybitWsPlaceOrderParams> for BybitWsPlaceOrderParams
Sourcefn from(params: BybitWsPlaceOrderParams) -> Self
fn from(params: BybitWsPlaceOrderParams) -> Self
Converts to this type from the input type.
Sourceimpl<'a, 'py> FromPyObject<'a, 'py> for BybitWsPlaceOrderParamswhere
Self: Clone,
impl<'a, 'py> FromPyObject<'a, 'py> for BybitWsPlaceOrderParamswhere
Self: Clone,
Sourceimpl<'py> IntoPyObject<'py> for BybitWsPlaceOrderParams
impl<'py> IntoPyObject<'py> for BybitWsPlaceOrderParams
Sourcetype Target = BybitWsPlaceOrderParams
type Target = BybitWsPlaceOrderParams
The Python output type
Sourcetype Output = Bound<'py, <BybitWsPlaceOrderParams as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <BybitWsPlaceOrderParams as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PyClass for BybitWsPlaceOrderParams
impl PyClass for BybitWsPlaceOrderParams
Sourceimpl PyClassImpl for BybitWsPlaceOrderParams
impl PyClassImpl for BybitWsPlaceOrderParams
Sourceconst MODULE: Option<&str> = ::core::option::Option::None
const MODULE: Option<&str> = ::core::option::Option::None
Module which the class will be associated with. Read more
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = /// Parameters for placing an order via WebSocket.
const RAW_DOC: &'static CStr = /// Parameters for placing an order via WebSocket.
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype Layout = <<BybitWsPlaceOrderParams as PyClassImpl>::BaseNativeType as PyClassBaseType>::Layout<BybitWsPlaceOrderParams>
type Layout = <<BybitWsPlaceOrderParams as PyClassImpl>::BaseNativeType as PyClassBaseType>::Layout<BybitWsPlaceOrderParams>
Description of how this class is laid out in memory
Sourcetype ThreadChecker = NoopThreadChecker
type ThreadChecker = NoopThreadChecker
This handles following two situations: Read more
type Inventory = Pyo3MethodsInventoryForBybitWsPlaceOrderParams
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<PyObjectOffset>
fn dict_offset() -> Option<PyObjectOffset>
Used to provide the dictoffset slot
(equivalent to tp_dictoffset)
fn weaklist_offset() -> Option<PyObjectOffset>
fn weaklist_offset() -> Option<PyObjectOffset>
Used to provide the weaklistoffset slot
(equivalent to tp_weaklistoffset
Sourceimpl PyClassNewTextSignature for BybitWsPlaceOrderParams
impl PyClassNewTextSignature for BybitWsPlaceOrderParams
const TEXT_SIGNATURE: &'static str = "(category, symbol, side, order_type, qty, is_leverage=None, market_unit=None, price=None, time_in_force=None, order_link_id=None, reduce_only=None, close_on_trigger=None, trigger_price=None, trigger_by=None, trigger_direction=None, tpsl_mode=None, take_profit=None, stop_loss=None, tp_trigger_by=None, sl_trigger_by=None, sl_trigger_price=None, tp_trigger_price=None, sl_order_type=None, tp_order_type=None, sl_limit_price=None, tp_limit_price=None, order_iv=None, mmp=None, position_idx=None)"
Sourceimpl PyStubType for BybitWsPlaceOrderParams
impl PyStubType for BybitWsPlaceOrderParams
Sourcefn type_output() -> TypeInfo
fn type_output() -> TypeInfo
The type to be used in the output signature, i.e. return type of the Python function or methods.
fn type_input() -> TypeInfo
fn type_input() -> TypeInfo
The type to be used in the input signature, i.e. the arguments of the Python function or methods. Read more
Sourceimpl PyTypeInfo for BybitWsPlaceOrderParams
impl PyTypeInfo for BybitWsPlaceOrderParams
Sourceconst NAME: &str = <Self as ::pyo3::PyClass>::NAME
const NAME: &str = <Self as ::pyo3::PyClass>::NAME
👎Deprecated since 0.28.0:
prefer using ::type_object(py).name() to get the correct runtime value
Class name.
Sourceconst MODULE: Option<&str> = <Self as ::pyo3::impl_::pyclass::PyClassImpl>::MODULE
const MODULE: Option<&str> = <Self as ::pyo3::impl_::pyclass::PyClassImpl>::MODULE
👎Deprecated since 0.28.0:
prefer using ::type_object(py).module() to get the correct runtime value
Module name, if any.
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type or a subclass of this type.fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type.Sourceimpl TryFrom<BybitWsPlaceOrderParams> for BybitWsPlaceOrderParams
impl TryFrom<BybitWsPlaceOrderParams> for BybitWsPlaceOrderParams
Sourcetype Error = BybitWsError
type Error = BybitWsError
The type returned in the event of a conversion error.
impl DerefToPyAny for BybitWsPlaceOrderParams